#!perl -T

use Test::More tests => 1;

BEGIN {
	use_ok( 'Parse::SpectrumDirect::RadioFrequency' );
}

diag( "Testing Parse::SpectrumDirect::RadioFrequency $Parse::SpectrumDirect::RadioFrequency::VERSION, Perl $], $^X" );
